@@ -4,7 +4,7 @@ use signature::{Signer, Verifier};
 
 pub type Error = signature::Error;
 
-#[derive(Debug, Clone, Copy, PartialEq, Eq, Serialize, Deserialize)]
+#[derive(Clone, Copy, PartialEq, Eq, Serialize, Deserialize)]
 pub struct PublicKey(ed25519::PublicKey);
 
 impl PublicKey {
@@ -17,6 +17,12 @@ impl PublicKey {
     }
 }
 
+impl core::fmt::Debug for PublicKey {
+    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+        core::fmt::Display::fmt(self, f)
+    }
+}
+
 impl core::fmt::Display for PublicKey {
     fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
         let bytes = self.0.to_bytes();
